Module system

Module system 

Types and functionality related to system functions

Structs

DeviceInfo
Information returned by the GetDeviceInfo API
FileHandle
Handle identifying an open file on the NXT brick
FindFileHandle
Handle identifying a file search session
FwVersion
Version information from the NXT brick
ModuleHandle
Handle identifying an open module iomap

Enums

BufType
Types of buffer that can be read

Functions

display_data_to_raster
Function to map the display iomap data onto a rectangular array
raster_to_string
Render the display raster into a string for printing to the terminal

Type Aliases

DisplayRaster
Type alias for the display raster