Types and functionality related to system functions
Structs
- Device
Info - Information returned by the
GetDeviceInfoAPI - File
Handle - Handle identifying an open file on the NXT brick
- Find
File Handle - Handle identifying a file search session
- FwVersion
- Version information from the NXT brick
- Module
Handle - Handle identifying an open module iomap
Enums
- BufType
- Types of buffer that can be read
Functions
- display_
data_ to_ raster - Function to map the display iomap data onto a rectangular array
- raster_
to_ string - Render the display raster into a string for printing to the terminal
Type Aliases
- Display
Raster - Type alias for the display raster